<?php

class WC_Trackdesk_Client {
	const CONVERSION_STATUS_APPROVED = 'CONVERSION_STATUS_APPROVED';
	const CONVERSION_STATUS_ON_HOLD = 'CONVERSION_STATUS_ON_HOLD';
	const CONVERSION_STATUS_PENDING = 'CONVERSION_STATUS_PENDING';
	const CONVERSION_STATUS_REFUNDED = 'CONVERSION_STATUS_REFUNDED';
	const CONVERSION_STATUS_REJECTED = 'CONVERSION_STATUS_REJECTED';

	private string $api_domain_root;

	private string $api_request_cookie;

	private bool $api_ssl_verified;

	private static $instance;

	protected function __construct() {
		$general = WC_Trackdesk_Settings::get_general();

		$this->api_domain_root    = $general[ WC_Trackdesk_Settings::GENERAL_SETTINGS_KEY_API_DOMAIN_ROOT ];
		$this->api_request_cookie = $general[ WC_Trackdesk_Settings::GENERAL_SETTINGS_KEY_API_REQUEST_COOKIE ];
		$this->api_ssl_verified   = $general[ WC_Trackdesk_Settings::GENERAL_SETTINGS_KEY_API_SSL_VERIFIED ];
	}

	public function create_conversion_by_external_cid(
		string $tenant_id,
		string $api_key,
		string $external_cid,
		string $revenue_origin_id,
		string $conversion_type_code,
		string $status,
		string $amount,
		string $external_id,
		?string $customer_id
	): void {
		$api_domain = $this->api_domain( $tenant_id );
		$url        = "https://{$api_domain}/tracking/conversion/v1";
		$args       = [
			'method'    => 'POST',
			'sslverify' => $this->api_ssl_verified,
			'headers'   => [
				'content-type' => 'application/json',
				'x-api-key'    => $api_key,
			],
			'body'      => wp_json_encode( [
				'external_cid'         => $external_cid,
				'revenue_origin_id'    => $revenue_origin_id,
				'conversion_type_code' => $conversion_type_code,
				'status'               => $status,
				'amount'               => [
					"value" => $amount
				],
				'external_id'          => $external_id,
				"customer_id"          => $customer_id
			] ),
		];

		if ( $this->api_request_cookie !== '' ) {
			$args['cookies'] = [
				new WP_Http_Cookie( $this->api_request_cookie ),
			];
		}

		wp_remote_request( $url, $args );
	}

	public function update_conversion_status(
		string $tenant_id,
		string $api_key,
		string $revenue_origin_id,
		string $external_id,
		string $conversion_type_code,
		string $status
	): void {
		$api_domain = $this->api_domain( $tenant_id );
		$url        = "https://{$api_domain}/api/node/conversions/v1/update-status-by-external-id";
		$args       = [
			'method'    => 'POST',
			'sslverify' => $this->api_ssl_verified,
			'headers'   => [
				'content-type' => 'application/json',
				'x-api-key'    => $api_key,
			],
			'body'      => wp_json_encode( [
				'revenue_origin_id'    => $revenue_origin_id,
				'external_id'          => $external_id,
				'conversion_type_code' => $conversion_type_code,
				'status'               => $status,
			] ),
		];

		if ( $this->api_request_cookie !== '' ) {
			$args['cookies'] = [
				new WP_Http_Cookie( $this->api_request_cookie ),
			];
		}

		wp_remote_request( $url, $args );
	}

	public function api_domain( string $tenant_id ): string {
		return "{$tenant_id}.{$this->api_domain_root}";
	}

	public static function convert_offer_status_to_conversion_status( string $offer_status ): ?string {
		switch ( $offer_status ) {
			case 'pending':
			case 'processing':
				return self::CONVERSION_STATUS_PENDING;
			case 'on-hold':
				return self::CONVERSION_STATUS_ON_HOLD;
			case 'completed':
				return self::CONVERSION_STATUS_APPROVED;
			case 'cancelled':
			case 'failed':
				return self::CONVERSION_STATUS_REJECTED;
			case 'refunded':
				return self::CONVERSION_STATUS_REFUNDED;
			default:
				return null;
		}
	}

	public static function instance(): WC_Trackdesk_Client {
		if ( self::$instance === null ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
}
