<?php

class WC_Trackdesk_Hooks {
	private WC_Trackdesk_Client $trackdesk_client;

	private static $instance;

	protected function __construct() {
		$this->trackdesk_client = WC_Trackdesk_Client::instance();

		add_action( 'woocommerce_order_edit_status', array( $this, 'update_conversion_status' ), 10, 2 );

		if ( WC_Trackdesk_Utils::is_wc_subscription_activated() ) {
			add_filter( 'wcs_new_order_created', array( $this, 'add_readonly_action_on_wcs_new_order_created' ), 11, 2 );
		}
	}

	public function add_readonly_action_on_wcs_new_order_created( WC_Order $order, WC_Subscription $subscription ): WC_Order {
		self::create_conversion_on_subscription_renewal( $order, $subscription );

		return $order;
	}

	public function create_conversion_on_subscription_renewal( WC_Order $order, WC_Subscription $subscription ): void {
		$conversion_status = WC_Trackdesk_Client::convert_offer_status_to_conversion_status( $order->get_status() );

		foreach ( WC_Trackdesk_Settings::get_tenants() as $tenant ) {
			if ( ! $tenant[ WC_Trackdesk_Settings::TENANT_SETTING_KEY_CONVERSION_ON_SUBSCRIPTION_RENEWAL ] ) {
				continue;
			}

			$tenant_id            = $tenant[ WC_Trackdesk_Settings::TENANT_SETTING_KEY_ID ];
			$api_key              = $tenant[ WC_Trackdesk_Settings::TENANT_SETTING_KEY_API_KEY ];
			$revenue_origin_id    = $tenant[ WC_Trackdesk_Settings::TENANT_SETTING_KEY_REVENUE_ORIGIN_ID ];
			$conversion_type_code = $tenant[ WC_Trackdesk_Settings::TENANT_SETTING_KEY_ORDER_RECEIVED_CONVERSION_TYPE_CODE ];
			$customer_id_filled   = $tenant[ WC_Trackdesk_Settings::TENANT_SETTING_KEY_CUSTOMER_ID_FILLED ];

			$this->trackdesk_client->create_conversion_by_external_cid(
				$tenant_id,
				$api_key,
				WC_Trackdesk_Utils::get_subscription_external_cid( $subscription->get_id() ),
				$revenue_origin_id,
				$conversion_type_code,
				$conversion_status,
				strval( WC_Trackdesk_Utils::get_conversion_amount_from_order( $order ) ),
				strval( $order->get_id() ),
				$customer_id_filled ? $order->get_billing_email() : null,
			);
		}
	}

	public function update_conversion_status( int $order_id, string $new_order_status ): void {
		$conversion_status = WC_Trackdesk_Client::convert_offer_status_to_conversion_status( $new_order_status );

		if ( ! $conversion_status ) {
			return;
		}

		$tenants = WC_Trackdesk_Settings::get_tenants();

		foreach ( $tenants as $tenant ) {
			$tenant_id            = $tenant[ WC_Trackdesk_Settings::TENANT_SETTING_KEY_ID ];
			$api_key              = $tenant[ WC_Trackdesk_Settings::TENANT_SETTING_KEY_API_KEY ];
			$revenue_origin_id    = $tenant[ WC_Trackdesk_Settings::TENANT_SETTING_KEY_REVENUE_ORIGIN_ID ];
			$conversion_type_code = $tenant[ WC_Trackdesk_Settings::TENANT_SETTING_KEY_ORDER_RECEIVED_CONVERSION_TYPE_CODE ];

			$this->trackdesk_client->update_conversion_status(
				$tenant_id,
				$api_key,
				$revenue_origin_id,
				strval( $order_id ),
				$conversion_type_code,
				$conversion_status,
			);
		}
	}

	public static function instance(): WC_Trackdesk_Hooks {
		if ( self::$instance === null ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
}
